@@ -22,7 +22,7 @@ from time import sleep
 from typing import TYPE_CHECKING, Any, Optional, Set, Union
 
 from robot.libraries.BuiltIn import BuiltIn
-from robot.utils import timestr_to_secs  # type: ignore
+from robot.utils import timestr_to_secs
 
 from ..generated.playwright_pb2 import Response
 from ..utils import SettingsStack, get_variable_value, logger
@@ -167,7 +167,7 @@ class LibraryComponent:
         return secret
 
     def decrypt_with_crypto_library(self, secret):
-        if not isinstance(secret, str) or not re.match(r'^crypt:(.*)', secret):
+        if not isinstance(secret, str) or not re.match(r"^crypt:(.*)", secret):
             return secret
         logger.trace("CryptoLibrary string pattern found.")
         self._import_crypto_library()
@@ -185,19 +185,24 @@ class LibraryComponent:
         if self._crypto is None:
             try:
                 try:
-                    logger.trace('Trying to import CryptoLibrary instance from Robot Framework.')
+                    logger.trace(
+                        "Trying to import CryptoLibrary instance from Robot Framework."
+                    )
                     crypto_library = BuiltIn().get_library_instance("CryptoLibrary")
                     self._crypto = crypto_library.crypto
                 except RuntimeError:
-                    logger.trace('Getting CryptoLibrary failed, trying to import directly.')
+                    logger.trace(
+                        "Getting CryptoLibrary failed, trying to import directly."
+                    )
                     from CryptoLibrary.utils import CryptoUtility  # type: ignore
+
                     self._crypto = CryptoUtility()
             except ImportError:
                 logger.trace(traceback.format_exc())
-                logger.trace('CryptoLibrary import failed, using plain string.')
+                logger.trace("CryptoLibrary import failed, using plain string.")
                 self._crypto = False
                 return
-            logger.trace('CryptoLibrary import succeeded.')
+            logger.trace("CryptoLibrary import succeeded.")
 
     def _replace_placeholder_variables(self, placeholder):
         if isinstance(placeholder, dict):
