@@ -19,7 +19,7 @@ from datetime import timedelta
 from pathlib import Path
 from typing import Dict, List, Optional, Union
 
-from robot.utils import get_link_path  # type: ignore
+from robot.utils import get_link_path
 
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
@@ -121,6 +121,7 @@ class Control(LibraryComponent):
         | `Take Screenshot`   selector=id=username_field    # Captures element in image
         | # Takes screenshot with jpeg extension, defines image quality and timeout how long taking screenhost should last
         | `Take Screenshot`   fullPage=True    fileType=jpeg    quality=50    timeout=10s
+        | `Take Screenshot`   EMBED                         # Screenshot is embedded as Base64 image to the log.html.
 
         [https://forum.robotframework.org/t//4337|Comment >>]
         """
